ReadError

Enum ReadError 

pub enum ReadError {
    IncompleteItem {
        item: &'static str,
        offset: usize,
        expected: usize,
        found: usize,
    },
    InvalidItem {
        item: &'static str,
        offset: usize,
        expected: &'static str,
        found: String,
    },
    InvalidHeader(InvalidHeader),
}
Error that ocurred while reading an item from the byte stream.

Variants



IncompleteItem

Insufficient data in the byte stream.

Fields

item: &'static str

The specific item that was trying to parse.

offset: usize

The offset in the byte stream where the error ocurred.

expected: usize

The expected length of the input (for this item).

found: usize

The number of bytes found in the byte stream.



InvalidItem

An item was invalid after parsing.

Fields

item: &'static str

The item that was trying to parse.

offset: usize

The offset in the byte stream where the error ocurred.

expected: &'static str

A hint at what was expected.

found: String

Message indicating what was actually found.



InvalidHeader(InvalidHeader)

Failed to validate the header.

Implementations

Source

impl ReadError

pub(super) const fn set_item(self, item: &'static str) -> Self