#[non_exhaustive]pub struct ProofNode {
pub key: PathBuf,
pub partial_len: usize,
pub value_digest: Option<ValueDigest<Value>>,
pub child_hashes: Children<Option<HashType>>,
}Expand description
A node in a proof.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key: PathBufThe key this node is at. Each byte is a nibble.
partial_len: usizeThe length of the key prefix that is shared with the previous node.
value_digest: Option<ValueDigest<Value>>None if the node does not have a value. Otherwise, the node’s value or the hash of its value.
child_hashes: Children<Option<HashType>>The hash of each child, or None if the child does not exist.